@@ -68,7 +68,7 @@ Return the output of running 'command', or nil on error."
              (raw-output (buffer-string))
              (output
              ; Added by some Emacs call-process apparently
-              (replace-regexp-in-string "\nProcess perly_sense --stdin finished\n" "" raw-output))
+              (replace-regexp-in-string "\nProcess[ ]+perly_sense[ ]+--stdin[ ]+finished[ ]*?\n" "" raw-output))
              )
 ;;        (message "Pool output: (%s)" output)
         (kill-buffer scp/buffer-command-running)
